::cisco::eem::event_register_timer watchdog time 60 name "nat_pool_timer"

if { ![info exists nat_pool_name] } {
    set result "ERROR: Policy cannot be run: variable nat_pool_name has not been set"
    error $result $errorInfo
}

if { ![info exists nat_pool_threshold] } {
    set result "ERROR: Policy cannot be run: variable nat_pool_threshold has not been set"
    error $result $errorInfo
}

namespace import ::cisco::eem::*
namespace import ::cisco::lib::*

proc run_cli { clist } {
    set rbuf ""

    if {[llength $clist] < 1} {
	return -code ok $rbuf
    }

    if {[catch {cli_open} result]} {
        return -code error $result
    } else {
	array set cliarr $result
    }

    if {[catch {cli_exec $cliarr(fd) "enable"} result]} {
        return -code error $result
    }

    if {[catch {cli_exec $cliarr(fd) "term length 0"} result]} {
        return -code error $result
    }

    foreach cmd $clist {
	if {[catch {cli_exec $cliarr(fd) $cmd} result]} {
            return -code error $result
	}

	append rbuf $result
    }

    if {[catch {cli_close $cliarr(fd) $cliarr(tty_id)} result]} {
        puts "WARNING: $result"
    }

    return -code ok $rbuf
}

proc run_cli_interactive { clist } {
    set rbuf ""

    if {[llength $clist] < 1} {
	return -code ok $rbuf
    }

    if {[catch {cli_open} result]} {
        return -code error $result
    } else {
	array set cliarr $result
    }

    if {[catch {cli_exec $cliarr(fd) "enable"} result]} {
        return -code error $result
    }

    if {[catch {cli_exec $cliarr(fd) "term length 0"} result]} {
        return -code error $result
    }

    foreach cmd $clist {
        array set sendexp $cmd

	if {[catch {cli_write $cliarr(fd) $sendexp(send)} result]} {
            return -code error $result
	}

	foreach response $sendexp(responses) {
	    array set resp $response

	    if {[catch {cli_read_drain $cliarr(fd)} result]} {
                return -code error $result
	    }

	    if {![regexp $resp(expect) $result]} {
		return -code error $result
	    }

	    if {[catch {cli_write $cliarr(fd) $resp(reply)} result]} {
                return -code error $result
	    }
	}

	if {[catch {cli_read $cliarr(fd)} result]} {
            return -code error $result
	}

	append rbuf $result
    }

    if {[catch {cli_close $cliarr(fd) $cliarr(tty_id)} result]} {
        puts "WARNING: $result"
    }

    return -code ok $rbuf
}

set command "show ip nat statistics | inc Total active translations"

set output [run_cli [list $command]]

if { [regexp {translations:\s+(\d+)} $output -> trans] } {
    set usage [expr int([expr [expr $trans / 100.0] * 100.0])]
	if { $usage >= $nat_pool_threshold } {
		action_syslog msg "NAT pool $nat_pool_name is at ${usage}% capacity"
		if { [info exists _email_server] && [info exists nat_pool_email_template] } {
	        set devname [info hostname]
	        if { [catch {smtp_subst [file $nat_pool_email_template]} result] } {
		    error $result $errorInfo
	        }

	        if { [catch {smtp_send_email $result} result] } {
		    error $result $errorInfo
	        }
		break
	    }
	    }

}
